\name{Discrete}
\alias{ddiscrete}
\alias{pdiscrete}
\alias{qdiscrete}
\alias{rdiscrete}
\alias{aliasmat}
\alias{aliasmat2prob}
\title{Discrete Distribution}
\description{
  These functions provide information about the discrete distribution
  where the probability of the elements of \code{values} is proportional
  to the values given in \code{probs}, which are normalized to sum up to
  1.  \code{ddiscrete} gives the density, \code{pdiscrete} gives the
  distribution function, \code{qdiscrete} gives the quantile function
  and \code{rdiscrete} generates random deviates.
}
\usage{
ddiscrete(x, probs, values = 1:length(probs))
pdiscrete(q, probs, values = 1:length(probs))
qdiscrete(p, probs, values = 1:length(probs))
rdiscrete(n, probs, values = 1:length(probs), ...)
}
\arguments{
  \item{x,q}{vector or array of quantiles.}
  \item{p}{vector or array of probabilites.}
  \item{n}{number of observations.}
  \item{probs}{probabilities of the distribution.}
  \item{values}{values of the distribution.}
  \item{...}{ignored (only there for backwards compatibility)}
}
\details{
  The random number generator is simply a wrapper for
  \code{\link{sample}} and provided for backwards compatibility only.
}
\author{Andreas Weingessel and Friedrich Leisch}
\examples{
## a vector of length 30 whose elements are 1 with probability 0.2
## and 2 with probability 0.8.
rdiscrete (30, c(0.2, 0.8))

## a vector of length 100 whose elements are A, B, C, D.
## The probabilities of the four values have the relation 1:2:3:3
rdiscrete (100, c(1,2,3,3), c("A","B","C","D"))

}
\keyword{distribution}
\eof
\name{HouseVotes84}
\alias{HouseVotes84}
\title{United States Congressional Voting Records 1984}
\usage{data(HouseVotes84)}
\description{
    This data set includes votes for each of the U.S. House of
    Representatives Congressmen on the 16 key votes identified by the
    CQA.  The CQA lists nine different types of votes: voted for, paired
    for, and announced for (these three simplified to yea), voted
    against, paired against, and announced against (these three
    simplified to nay), voted present, voted present to avoid conflict
    of interest, and did not vote or otherwise make a position known
    (these three simplified to an unknown disposition).
}
\keyword{datasets}
\format{
    A data frame with 435 observations on 17 variables:
    \tabular{rl}{
   1 \tab Class Name: 2 (democrat, republican)\cr
   2 \tab handicapped-infants: 2 (y,n)\cr
   3 \tab water-project-cost-sharing: 2 (y,n)\cr
   4 \tab adoption-of-the-budget-resolution: 2 (y,n)\cr
   5 \tab physician-fee-freeze: 2 (y,n)\cr
   6 \tab el-salvador-aid: 2 (y,n)\cr
   7 \tab religious-groups-in-schools: 2 (y,n)\cr
   8 \tab anti-satellite-test-ban: 2 (y,n)\cr
   9 \tab aid-to-nicaraguan-contras: 2 (y,n)\cr
  10 \tab mx-missile: 2 (y,n)\cr
  11 \tab immigration: 2 (y,n)\cr
  12 \tab synfuels-corporation-cutback: 2 (y,n)\cr
  13 \tab education-spending: 2 (y,n)\cr
  14 \tab superfund-right-to-sue: 2 (y,n)\cr
  15 \tab crime: 2 (y,n)\cr
  16 \tab duty-free-exports: 2 (y,n)\cr
  17 \tab export-administration-act-south-africa: 2 (y,n)\cr
  }
}
\source{
    \itemize{
	\item Source: Congressional Quarterly Almanac, 98th Congress,
	2nd session 1984, Volume XL: Congressional Quarterly Inc.,
	ington, D.C., 1985
	\item Donor: Jeff Schlimmer (Jeffrey.Schlimmer@a.gp.cs.cmu.edu)
    }

    These data have been taken from the UCI Repository Of Machine Learning
    Databases at
    \itemize{
      \item \url{ftp://ftp.ics.uci.edu/pub/machine-learning-databases}
      \item \url{http://www.ics.uci.edu/~mlearn/MLRepository.html}
    }
    and were converted to R format by Friedrich.Leisch@ci.tuwien.ac.at.
}
    
\eof
\name{bclust}
\alias{bclust}
\alias{hclust.bclust}
\alias{plot.bclust}
\alias{centers.bclust}
\alias{clusters.bclust}
\title{Bagged Clustering}
\usage{
bclust(x, centers=2, iter.base=10, minsize=0,
       dist.method="euclidian",
       hclust.method="average", base.method="kmeans",
       base.centers=20, verbose=TRUE,
       final.kmeans=FALSE, docmdscale=FALSE,
       resample=TRUE, weights=NULL, maxcluster=base.centers, ...)
hclust.bclust(object, x, centers, dist.method=object$dist.method,
              hclust.method=object$hclust.method, final.kmeans=FALSE,
              docmdscale = FALSE, maxcluster=object$maxcluster)
\method{plot}{bclust}(x, maxcluster=object$maxcluster, main, ...)
centers.bclust(object, k)
clusters.bclust(object, k, x=NULL)
}
\arguments{
  \item{x}{Matrix of inputs (or object of class \code{"bclust"} for plot).}
  \item{centers, k}{Number of clusters.}
  \item{iter.base}{Number of runs of the base cluster algorithm.}
  \item{minsize}{Minimum number of points in a base cluster.}
  \item{dist.method}{Distance method used for the hierarchical
    clustering, see \code{\link{dist}} for available distances.}
  \item{hclust.method}{Linkage method used for the hierarchical
    clustering, see \code{\link{hclust}} for available methods.}
  \item{base.method}{Partitioning cluster method used as base algorithm.}
  \item{base.centers}{Number of centers used in each repetition of the
    base method.}
  \item{verbose}{Output status messages.}
  \item{final.kmeans}{If \code{TRUE}, a final kmeans step is performed
    using the output of the bagged clustering as initialization.}
  \item{docmdscale}{Logical, if \code{TRUE} a \code{\link{cmdscale}}
    result is included in the return value.}
  \item{resample}{Logical, if \code{TRUE} the base method is run on
    bootstrap samples of \code{x}, else directly on \code{x}.}
  \item{weights}{Vector of length \code{nrow(x)}, weights for the
    resampling. By default all observations have equal weight.}
  \item{maxcluster}{Maximum number of clusters memberships are to be
    computed for.}
  \item{object}{Object of class \code{"bclust"}.}
  \item{main}{Main title of the plot.}
  \item{\dots}{Optional arguments top be passed to the base method
    in \code{bclust}, ignored in \code{plot}.}
}
\description{
    Cluster the data in \code{x} using the bagged clustering
    algorithm. A partitioning cluster algorithm such as
    \code{\link{kmeans}} is run repeatedly on bootstrap samples from the
    original data. The resulting cluster centers are then combined using
    the hierarchical cluster algorithm \code{\link{hclust}}.
}
\details{
    First, \code{iter.base} bootstrap samples of the original data in
    \code{x} are created by drawing with replacement. The base cluster
    method is run on each of these samples with \code{base.centers}
    centers. The \code{base.method} must be the name of a partitioning
    cluster function returning a list with the same components as the
    return value of \code{\link{kmeans}}.

    This results in a collection of \code{iter.base *
	base.centers} centers, which are subsequently clustered using
    the hierarchical method \code{\link{hclust}}. Base centers with less
    than \code{minsize} points in there respective partitions are removed
    before the hierarchical clustering.

    The resulting dendrogram is then cut to produce \code{centers}
    clusters. Hence, the name of the argument \code{centers} is a little
    bit misleading as the resulting clusters need not be convex, e.g.,
    when single linkage is used. The name was chosen for compatibility 
    with standard partitioning cluster methods such as
    \code{\link{kmeans}}.

    A new hierarchical clustering (e.g., using another
    \code{hclust.method}) re-using previous base runs can be
    performed by running \code{hclust.bclust} on the return value of
    \code{bclust}. 
}
\value{
    \code{bclust} and \code{hclust.bclust} return objects of class
    \code{"bclust"} including the components 
    \item{hclust}{Return value of the hierarchical clustering of the
	collection of base centers (Object of class \code{"hclust"}).}
    \item{cluster}{Vector with indices of the clusters the inputs are
	assigned to.}
    \item{centers}{Matrix of centers of the final clusters. Only useful,
	if the hierarchical clustering method produces convex clusters.}
    \item{allcenters}{Matrix of all \code{iter.base * base.centers}
	centers found in the base runs.}
}
\author{Friedrich Leisch}
\references{
  Friedrich Leisch. Bagged clustering. Working Paper 51, SFB ``Adaptive
  Information Systems and Modeling in Economics and Management
  Science'', August 1999. \url{http://www.ci.tuwien.ac.at/~leisch}}
\seealso{\code{\link{hclust}}, \code{\link{kmeans}},
  \code{\link{boxplot.bclust}}}
\keyword{multivariate}
\keyword{cluster}
\examples{
data(iris)
bc1 <- bclust(iris[,1:4], 3, base.centers=5)
plot(bc1)

table(clusters.bclust(bc1, 3))
centers.bclust(bc1, 3)
}

\eof
\name{bincombinations}
\title{Binary Combinations}
\usage{
bincombinations(p)
}
\alias{bincombinations}
\arguments{
 \item{p}{Length of binary vectors}
}
\description{
  Returns a matrix containing the \eqn{2^p} vectors of length \code{p}.
}
\author{Friedrich Leisch}
\examples{
bincombinations(2)
bincombinations(3)
}
\keyword{utilities}
\eof
\name{bootstrap.lca}

\alias{bootstrap.lca}
\alias{print.bootstrap.lca}

\title{Bootstrap Samples of LCA Results}
\description{
This function draws bootstrap samples from a given LCA model and refits
a new LCA model for each sample. The quality of fit of these models is
compared to the original model.
}
\usage{
bootstrap.lca(l, nsamples=10, lcaiter=30, verbose=FALSE)
}

\arguments{
  \item{l}{An LCA model as created by \code{\link{lca}}}
  \item{nsamples}{Number of bootstrap samples}
  \item{lcaiter}{Number of LCA iterations}
  \item{verbose}{If \code{TRUE} some output is printed during the
    computations.} 
}
\details{
From a given LCA model \code{l}, \code{nsamples} bootstrap samples are
drawn. For each sample a new LCA model is fitted. The goodness of fit
for each model is computed via Likelihood Ratio and Pearson's
Chisquare. The values for the fitted models are compared with the values
of the original model \code{l}. By this method it can be tested whether
the data to which \code{l} was originally fitted come from an LCA model.
}
\value{
  An object of class \code{bootstrap.lca} is returned, containing
  \item{logl, loglsat}{The LogLikelihood of the models and of the
    corresponding saturated models}
  \item{lratio}{Likelihood quotient of the models and the coresponding
    saturated models}
  \item{lratiomean, lratiosd}{Mean and Standard deviation of
    \code{lratio}}
  \item{lratioorg}{Likelihood quotient of the original model and the
    correspomdiong saturated model}
  \item{zratio}{Z-Statistics of \code{lratioorg}}
  \item{pvalzratio, pvalratio}{P-Values for \code{zratio}, computed via normal
    distribution and empirical distribution}
  \item{chisq}{Pearson's Chisq of the models}
  \item{chisqmean, chisqsd}{Mean and Standard deviation of
    \code{chisq}}
  \item{chisqorg}{Pearson's Chisq of the original model}
  \item{zchisq}{Z-Statistics of \code{chisqorg}}
  \item{pvalzchisq, pvalchisq}{P-Values for \code{zchisq}, computed via normal
    distribution and empirical distribution}
  \item{nsamples}{Number of bootstrap samples}
  \item{lcaiter}{Number of LCA Iterations}
}
\references{Anton K. Formann: ``Die Latent-Class-Analysis'', Beltz
    Verlag 1984}

\author{Andreas Weingessel}
    
\seealso{\code{\link{lca}}}

\examples{
## Generate a 4-dim. sample with 2 latent classes of 500 data points each.
## The probabilities for the 2 classes are given by type1 and type2.
type1 <- c(0.8,0.8,0.2,0.2)
type2 <- c(0.2,0.2,0.8,0.8)
x <- matrix(runif(4000),nr=1000)
x[1:500,] <- t(t(x[1:500,])<type1)*1
x[501:1000,] <- t(t(x[501:1000,])<type2)*1

l <- lca(x, 2, niter=5)
bl <- bootstrap.lca(l,nsamples=3,lcaiter=5)
bl
}

\keyword{multivariate}

\eof
\name{boxplot.bclust}
\alias{boxplot.bclust}
\title{Boxplot of cluster profiles}
\usage{
\method{boxplot}{bclust}(x, n=nrow(bcobj$centers), bycluster=TRUE,
        main=deparse(substitute(bcobj)), oneplot=TRUE,
        which=1:n))
}
\arguments{
 \item{x}{Clustering result, object of class \code{"bclust"}.}% 
 \item{n}{Number of clusters to plot, by default the number of clusters
     used in the call of \code{\link{bclust}}.}
 \item{bycluster}{If \code{TRUE} (default), a boxplot for each cluster
     is plotted. If \code{FALSE}, a boxplot for each variable is plotted.}
 \item{main}{Main title of the plot, by default the name of the cluster
     object.} 
 \item{oneplot}{If \code{TRUE}, all boxplots appear on one screen (using
   an appropriate rectangular layout).}
 \item{which}{Number of clusters which should be plotted, default is all
   clusters.}
 \item{...}{Additional arguments for \code{\link{boxplot}}.}
}
\description{
    Makes boxplots of the results of a bagged clustering run.
}
\author{Friedrich Leisch}
\keyword{hplot}
\examples{
data(iris)
bc1 <- bclust(iris[,1:4], 3, base.centers=5)
boxplot(bc1)
}

\eof
\name{classAgreement}
\alias{classAgreement}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Coefficients comparing classification agreement}
\description{
  \code{classAgreement()} computes several coefficents of agreement
  between the columns and rows of a 2-way contingency table.
}
\usage{
classAgreement(tab, match.names=FALSE)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{tab}{A 2-dimensional contingency table.}
  \item{match.names}{Flag whether row and columns should be matched by name.}
}
\details{
Suppose we want to compare two classifications summarized by the
contingency table \eqn{T=[t_{ij}]} where \eqn{i,j=1,\ldots,K} and \eqn{t_{ij}}
denotes the number of data points which are in class \eqn{i} in the
first partition and in class \eqn{j} in the second partition. If both
classifications use the same labels, then obviously the two
classification agree completely if only elements in the main diagonal
of the table are non-zero. On the other hand, large off-diagonal
elements correspond to smaller agreement between the two
classifications. If \code{match.names} is \code{TRUE}, the class labels
as given by the row and column names are matched, i.e. only columns and
rows with the same dimnames are used for the computation.

If the two classification do not use the same set of labels, or if
identical labels can have different meaning (e.g., two outcomes of
cluster analysis on the same data set), then the situation is a little
bit more complicated. Let \eqn{A} denote the number of all pairs of data
points which are either put into the same cluster by both partitions or
put into different clusters by both partitions. Conversely, let \eqn{D}
denote the number of all pairs of data points that are put into one
cluster in one partition, but into different clusters by the other
partition.  Hence, the partitions disagree for all pairs \eqn{D} and
agree for all pairs \eqn{A}. We can measure the agreement by the Rand
index \eqn{A/(A+D)} which is invariant with respect to permutations of
the columns or rows of \eqn{T}.

Both indices have to be corrected for agreement by chance if the sizes
of the classes are not uniform.
}
\value{
  A list with components
  \item{diag}{Percentage of data points in the main diagonal of \code{tab}.}
  \item{kappa}{\code{diag} corrected for agreement by chance.}
  \item{rand}{Rand index.}
  \item{crand}{Rand index corrected for agreement by chance.}
}
\references{
J.~Cohen. A coefficient of agreement for nominal scales.
Educational and Psychological Measurement, 20, 37--46, 1960.

Lawrence Hubert and Phipps Arabie. Comparing partitions.
Journal of Classification, 2, 193--218, 1985.
}
\author{Friedrich Leisch}
\seealso{\code{\link{matchClasses}}}
\examples{
## no class correlations: both kappa and crand almost zero
g1 <- sample(1:5, size=1000, replace=TRUE)
g2 <- sample(1:5, size=1000, replace=TRUE)
tab <- table(g1, g2)
classAgreement(tab)

## let pairs (g1=1,g2=1) and (g1=3,g2=3) agree better
k <- sample(1:1000, size=200)
g1[k] <- 1
g2[k] <- 1

k <- sample(1:1000, size=200)
g1[k] <- 3
g2[k] <- 3

tab <- table(g1, g2)
## both kappa and crand should be significantly larger than before
classAgreement(tab)
}
\keyword{category}
\eof
\name{cmeans}
\alias{cmeans}
\alias{print.fclust}
\title{Fuzzy C-Means Clustering}
\usage{
cmeans (x, centers, iter.max=100, verbose=FALSE, dist="euclidean",
        method="cmeans", m=2, rate.par = NULL)
}
\arguments{
  \item{x}{The data matrix where columns correspond to variables and rows to observations}
  \item{centers}{Number of clusters or initial values for cluster centers}
  \item{iter.max}{Maximum number of iterations}
  \item{verbose}{If \code{TRUE}, make some output during learning}
  \item{dist}{Must be one of the following: If \code{"euclidean"}, the
    mean square error, if \code{"manhattan"}, the mean absolute error is
    computed. Abbreviations are also accepted.}
  \item{method}{If \code{"cmeans"}, then we have the cmeans fuzzy
    clustering method, if \code{"ufcl"} we have the On-line Update. Abbreviations in the method names are also accepted.}
  \item{m}{The degree of fuzzification. It is defined for values greater
    than 1}
  \item{rate.par}{The parameter of the learning rate} 
}
\description{
  The fuzzy version of the known \emph{k}means clustering algorithm as
  well as its online update (Unsupervised Fuzzy Competitive learning).  }
\details{
  
  The data given by \code{x} is clustered by the fuzzy \emph{k}means algorithm.
  
  If \code{centers} is a matrix, its rows are taken as the initial cluster
  centers. If \code{centers} is an integer, \code{centers} rows
  of \code{x} are randomly chosen as initial values.
  
  The algorithm stops when the maximum number of iterations (given by
  \code{iter.max}) is reached.

  If \code{verbose} is \code{TRUE}, it displays for each iteration the number
  the value of the objective function.

  If \code{dist} is \code{"euclidean"}, the distance between the
  cluster center and the data points is the Euclidean distance (ordinary
  fuzzy \emph{k}means algorithm). If \code{"manhattan"}, the distance
  between the cluster center and the data points is the sum of the
  absolute values of the distances of the coordinates.
  
  If \code{method} is \code{"cmeans"}, then we have the kmeans fuzzy
  clustering method. If \code{"ufcl"} we have the On-line Update
  (Unsupervised Fuzzy Competitive learning) method, which works by
  performing an update directly after each input signal. 

  The parameters \code{m} defines the degree of fuzzification. It is
  defined for real values greater than 1 and the bigger it is the more
  fuzzy the membership values of the clustered data points are.
  
  The parameter \code{rate.par} of the learning rate for the \code{"ufcl"}
  algorithm which is by default set to \code{rate.par=0.3} and is taking
  real values in (0 , 1).

}
\value{
  \code{cmeans} returns an object of class \code{"fclust"}.
  \item{centers}{The final cluster centers.}
  \item{size}{The number of data points in each cluster.}
  \item{cluster}{Vector containing the indices of the clusters where
    the data points are assigned to. The maximum membership value of a
    point is considered for partitioning it to a cluster.}
  \item{iter}{The number of iterations performed,} and
  \item{membership}{a matrix with the membership values of the data points
    to the clusters.}
  \item{withinerror}{Returns the sum of square distances within the
    clusters.} 
  \item{call}{Returns a call in which all of the arguments are
    specified by their names.}
 
}
\author{Evgenia Dimitriadou}
\references{
  Nikhil R. Pal, James C. Bezdek, and Richard J. Hathaway.
  \emph{Sequential Competitive Learning and the Fuzzy c-Means Clustering
  Algorithms.} Neural Networks, Vol. \bold{9}, No. 5, pp. 787-796, 1996.
  }
\examples{
# a 2-dimensional example
x<-rbind(matrix(rnorm(100,sd=0.3),ncol=2),
         matrix(rnorm(100,mean=1,sd=0.3),ncol=2))
cl<-cmeans(x,2,20,verbose=TRUE,method="cmeans",m=2)
print(cl)

# a 3-dimensional example
x<-rbind(matrix(rnorm(150,sd=0.3),ncol=3),
         matrix(rnorm(150,mean=1,sd=0.3),ncol=3),
         matrix(rnorm(150,mean=2,sd=0.3),ncol=3))
cl<-cmeans(x,6,20,verbose=TRUE,method="cmeans")
print(cl)

# assign classes to some new data
y<-rbind(matrix(rnorm(33,sd=0.3),ncol=3),
         matrix(rnorm(33,mean=1,sd=0.3),ncol=3),
         matrix(rnorm(3,mean=2,sd=0.3),ncol=3))
#         ycl<-predict(cl, y, type="both")
        }
}
\keyword{cluster}



\eof
\name{countpattern}
\alias{countpattern}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Count Binary Patterns}
\usage{
countpattern(x, matching=FALSE)
}
%- maybe also `usage' for other objects documented here.
\arguments{
 \item{x}{A matrix of binary observations}
 \item{matching}{If TRUE an additional vector is returned which stores
     which row belongs to which pattern}
}
\description{
Every row of the binary matrix \code{x} is transformed into a binary
pattern and these patterns are counted.
}
\value{
A vector of length \code{2\^ncol(x)} giving the number of times each
pattern occurs in the rows of \code{x}. The names of this vector are the
binary patterns. They are sorted according to their numeric value.
If \code{matching} is \code{TRUE}, a list of the following two vectors is returned.
  \item{pat}{Numbers of patterns as described above.}
  \item{matching}{Vector giving the position of the pattern of each row
      of \code{x} in \code{pat}.}
}

\author{Andreas Weingessel}

\examples{
xx <- rbind(c(1,0,0),c(1,0,0),c(1,0,1),c(0,1,1),c(0,1,1))
countpattern(xx)
countpattern(xx, matching=TRUE)
}

\keyword{multivariate}
\eof
\name{cshell}
\alias{cshell}
\title{Fuzzy C-Shell Clustering}
\usage{
cshell(x, centers, iter.max=100, verbose=FALSE, dist="euclidean",
       method="cshell", m=2, radius = NULL)
}
\arguments{
  \item{x}{The data matrix, were columns correspond to the variables and
    rows to observations.}
  \item{centers}{Number of clusters or initial values for cluster centers}
  \item{iter.max}{Maximum number of iterations}
  \item{verbose}{If \code{TRUE}, make some output during learning}
  \item{dist}{Must be one of the following: If \code{"euclidean"}, the
    mean square error, if \code{"manhattan"}, the mean absolute error is
    computed. Abbreviations are also accepted.}
  \item{method}{Currently, only the \code{"cshell"} method; the c-shell fuzzy
    clustering method}
  \item{m}{The degree of fuzzification. It is defined for values greater
    than \emph{1}}
  \item{radius}{The radius of resulting clusters} 
}
\description{
  The \emph{c}-shell clustering algorithm, the shell prototype-based version
  (ring prototypes) of the fuzzy \emph{k}means clustering method.
}
\details{
  
  The data given by \code{x} is clustered by the fuzzy \emph{c}-shell algorithm.
  
  If \code{centers} is a matrix, its rows are taken as the initial cluster
  centers. If \code{centers} is an integer, \code{centers} rows
  of \code{x} are randomly chosen as initial values.
  
  The algorithm stops when the maximum number of iterations (given by
  \code{iter.max}) is reached.

  If \code{verbose} is \code{TRUE}, it displays for each iteration the number
  the value of the objective function.

  If \code{dist} is \code{"euclidean"}, the distance between the
  cluster center and the data points is the Euclidean distance (ordinary
  kmeans algorithm). If \code{"manhattan"}, the distance between the
  cluster center and the data points is the sum of the absolute values
  of the distances of the coordinates.
  
  If \code{method} is \code{"cshell"}, then we have the \emph{c}-shell
  fuzzy clustering method.

  The parameters \code{m} defines the degree of fuzzification. It is
  defined for real values greater than 1 and the bigger it is the more
  fuzzy the membership values of the clustered data points are.
  
  The parameter \code{radius} is by default set to \emph{0.2} for every
  cluster.

}
\value{
  \code{cshell} returns an object of class \code{"cshell"}.
  \item{centers}{The final cluster centers.}
  \item{size}{The number of data points in each cluster.}
  \item{cluster}{Vector containing the indices of the clusters where
    the data points are assigned to. The maximum membership value of a
    point is considered for partitioning it to a cluster.}
  \item{iter}{The number of iterations performed.}
  \item{membership}{a matrix with the membership values of the data points
    to the clusters.}
  \item{withinerror}{Returns the sum of square distances within the
    clusters.} 
  \item{call}{Returns a call in which all of the arguments are
    specified by their names.}
  
}
\author{Evgenia Dimitriadou}
\references{
  Rajesh N. Dave. \emph{Fuzzy Shell-Clustering and Applications to Circle
  Detection in Digital Images.} Int. J. of General Systems, Vol. \bold{16},
  pp. 343-355, 1996.
}
\examples{
## a 2-dimensional example
x<-rbind(matrix(rnorm(50,sd=0.3),ncol=2),
         matrix(rnorm(50,mean=1,sd=0.3),ncol=2))
cl<-cshell(x,2,20,verbose=TRUE,method="cshell",m=2)
print(cl)

# assign classes to some new data
y<-rbind(matrix(rnorm(13,sd=0.3),ncol=2),
         matrix(rnorm(13,mean=1,sd=0.3),ncol=2))
#         ycl<-predict(cl, y, type="both")
        }
\keyword{cluster}
\eof
\name{e1071-internal}
\alias{prune.bclust}
\alias{scale.data.frame}
\alias{na.fail.matrix.csr}
\title{Internal e1071 functions}
\description{
  Internal e1071 functions.
}
\usage{
prune.bclust(object, x, minsize=1, dohclust=FALSE, ...)}
scale.data.frame(x, scale = TRUE, center = TRUE)
na.fail.matrix.csr(object, ...)
\details{
  These are not to be called by the user.
}
\keyword{internal}
\eof
\name{element}
\title{Extract Elements of an Array}
\usage{
element(x, i)
}
\alias{element}
\arguments{
 \item{x}{Array of arbitrary dimensionality.}
 \item{i}{Vector of the same length as \code{x} has dimension}.}
}
\description{
  Returns the element of \code{x} specified by \code{i}.
}
\author{Friedrich Leisch}
\seealso{\link{Extract}}
\examples{
x <- array(1:20, dim=c(2,5,2))
element(x, c(1,4,2))
}
\keyword{array}
\eof
\name{fclustIndex}
\title{Fuzzy Cluster Indexes (Validity/Performance Measures)}
\usage{fclustIndex(y, x, index = "all")}
\alias{fclustIndex}
\arguments{
  \item{y}{An object of a fuzzy clustering result of class \code{"fclust"}}
  \item{x}{Data matrix}
  \item{index}{The validity measures used: \code{"gath.geva"}, \code{"xie.beni"},
    \code{"fukuyama.sugeno"}, \code{"partition.coefficient"},
    \code{"partition.entropy"}, \code{"proportion.exponent"},
    \code{"separation.index"} and \code{"all"} for all the indexes.}}

    
\description{
  Calculates the values of several fuzzy validity measures. The values
  of the indexes can be independently used in order to evaluate and compare
  clustering partitions or even to determine the number of clusters
  existing in a data set.}

\details{
  The validity measures and a short description of them follows, where
  \eqn{N} is the number of data points, \eqn{u_{ij}} the values of the
  membership matrix, \eqn{v_j} the centers of the clusters and \eqn{k}
  te number of clusters.
  \describe{
    \item \bold{gath.geva}:
    Gath and Geva introduced 2 main criteria for comparing and finding
    optimal partitions based on the heuristics that a better clustering
    assumes clear separation between the clusters, minimal volume of the
    clusters and maximal number of data points concentrated in the
    vicinity of the cluster centroids. These indexes are only for the
    cmeans clustering algorithm valid.
    For the first, the ``fuzzy hypervolume'' we have:
    \eqn{F_{HV}=\sum_{j=1}^{c}{[\det(F_j)]}^{1/2}}, where
    \eqn{F_j=\frac{\sum_{i=1}^N
	u_{ij}(x_i-v_j)(x_i-v_j)^T}{\sum_{i=1}^{N}u_{ij}}}, for the
    case when the defuzzification parameter is 2.
    For the second, the ``average partition density'':
    \eqn{D_{PA}=\frac{1}{k}\sum_{j=1}^k\frac{S_j}{{[\det(F_j)]}^{1/2}}},
    where \eqn{S_j=\sum_{i=1}^N u_{ij}}.
    Moreover, the ``partition density'' which expresses the general
    partition density according to the physical definition of density
    is calculated by:
    \eqn{P_D=\frac{S}{F_{HV}}}, where \eqn{S=\sum_{j=1}^k\sum_{i=1}^N
      u_{ij}}.
    \item \bold{xie.beni}:
    This index is a function of the data set and the centroids of the
    clusters. Xie and Beni explained this index by writing it as a ratio
    of the total variation of the partition and the centroids $(U,V)$
    and the separation of the centroids vectors. The minimum values of
    this index under comparison support the best partitions.
    \eqn{u_{XB}(U,V;X)=\frac{\sum_{j=1}^k\sum_{i=1}^Nu_{ij}^2{||x_i-v_j||}^2}{N(\min_{j\neq l}\{{||v_j-v_l||}^2\})}}
    \item \bold{fukuyama.sugeno}:
    This index consists of the difference of two terms, the first
    combining the fuzziness in the membership matrix with the
    geometrical compactness of the representation of the data set via
    the prototypes, and the second the fuzziness in its row of the
    partition matrix with the distance from the $i$th prototype to the
    grand mean of the data. The minimum values of this index also
    propose a good partition.
    \eqn{u_{FS}(U,V;X)=\sum_{i=1}^{N}\sum_{j=1}^k
      (u_{ij}^2)^q(||x_i-v_j||^2-||v_j-\bar v||^2)}
    \item \bold{partition.coefficient}:
    An index which measures the fuzziness of the partition but without
    considering the data set itself. It is a heuristic measure since it
    has no connection to any property of the data. The maximum values of
    it imply a good partition in the meaning of a least fuzzy
    clustering.
    \eqn{F(U;k)=\frac{tr (UU^T)}{N}=\frac{<U,U>}{N}=\frac{||U||^2}{N}}
    \itemize{
      \item \eqn{F(U;k)} shows the fuzziness or the overlap of the partition
      and depends on \eqn{kN} elements. 
      \item \eqn{1/k\leq F(U;k)\leq 1}, where if \eqn{F(U;k)=1} then \eqn{U} is a hard
      partition and if \eqn{F(U;k)=1/k} then \eqn{U=[1/k]} is the centroid of
      the fuzzy partion space \eqn{P_{fk}}. The converse is also valid.
    }
    \item \bold{partition.entropy}:
    It is a measure that provides information about the membership
    matrix without also considering the data itself. The minimum values
    imply a good partition in the meaning of a more crisp partition.
    \eqn{H(U;k)=\sum_{i=1}^{N} h(u_i)/N}, where
    \eqn{h(u)=-\sum_{j=1}^{k} u_j\,\log _a (u_j)} the Shannon's entropy.
    \itemize{
      \item \eqn{H(U;k)} shows the uncertainty of a fuzzy partition and
      depends also on \eqn{kN} elements. Specifically, \eqn{h(u_i)} is
      interpreted as the amount of fuzzy information about the
      membership of \eqn{x_i} in \eqn{k} classes that is retained by column
      \eqn{u_j}. Thus, at \eqn{U=[1/k]} the most information is withheld since
      the membership is the fuzziest possible.
      \item \eqn{0\leq H(U;k)\leq \log_a(k)}, where for \eqn{H(U;k)=0} \eqn{U} is a
      hard partition and for \eqn{H(U;k)=\log_a(k)} \eqn{U=[1/k]}.
    }
    \item \bold{proportion.exponent}:
    It is a measure \eqn{P(U;k)} of fuzziness adept to detect structural variations
    in the partition matrix as it becomes more fuzzier. A crisp cluster
    in the partition matrix can drive it to infinity when the partition
    coefficient and the partition entropy are more sensitive to small
    changes when approaching a hard partition. Its evaluation does not also
    involve the data or the algorithm used to partition them and
    its maximum implies the optimal partition but without knowing what
    maximum is a statistically significant maximum.
    \itemize{
      \item \eqn{0\leq P(U;k)<\infty}, since the \eqn{[0,1]} values explode to
      \eqn{[0,\infty)} due to the natural logarithm. Specifically, \eqn{P=0}
      when and only when \eqn{U=[1/k]}, while \eqn{P\rightarrow\infty} when
      any column of \eqn{U} is crisp. 
      \item \eqn{P(U;k)} can easily explode and it is good for partitions
      with large column maximums and at detecting structural variations.}
    \item \bold{separation.index (known as CS Index)}:
    This index identifies unique cluster structure with well-defined
    properties that depend on the data and a measure of distance. It
    answers the question if the clusters are compact and separated, but
    it rather seems computationally infeasible for big data sets since a
    distance matrix between all the data membership values has to be
    calculated. It also presupposes that a hard partition is derived
    from the fuzzy one.\cr
    \eqn{D_1(U;k;X,d)=\min_{i+1\,\leq\,l\,\leq\,k-1}\left\{\min_{1\,\leq\,j\,\leq\,k}\left\{\frac{dis(u_j,u_l)}{\max_{1\leq m\leq k}\{dia(u_m)\}}\right\}\right\}}, where \eqn{dia}  is the diameter of the subset, \eqn{dis} the distance of
    two subsets, and \eqn{d} a metric.
    \eqn{U} is a CS partition of \eqn{X} \eqn{\Leftrightarrow D_1>1}. When this
    holds then \eqn{U} is unique.
  }
}


\value{
  Returns a vector with the validity measures values.
}
\references{
  James C. Bezdek, \emph{Pattern Recognition with Fuzzy Objective
    Function Algorithms}, Plenum Press, 1981, NY.\cr
  L. X. Xie and G. Beni, \emph{Validity measure for fuzzy
    clustering}, IEEE Transactions on Pattern Analysis and Machine
  Intelligence, vol. \bold{3}, n. 8, p. 841-847, 1991.\cr
  I. Gath and A. B. Geva, \emph{Unsupervised Optimal Fuzzy
    Clustering}, IEEE Transactions on Pattern Analysis and Machine
  Intelligence, vol. \bold{11}, n. 7, p. 773-781, 1989.\cr
  Y. Fukuyama and M. Sugeno, \emph{A new method of choosing the
    number of clusters for the fuzzy $c$-means method}, Proc. 5th Fuzzy
  Syst. Symp., p. 247-250, 1989 (in japanese).}}

\author{Evgenia Dimitriadou}

\seealso{\code{\link{cmeans}}}

\examples{
# a 2-dimensional example
x<-rbind(matrix(rnorm(100,sd=0.3),ncol=2),
         matrix(rnorm(100,mean=1,sd=0.3),ncol=2))
cl<-cmeans(x,2,20,verbose=TRUE,method="cmeans")
resultindexes <- fclustIndex(cl,x, index="all")
resultindexes   
}
\keyword{cluster}

\eof
\name{hamming.distance}
\alias{hamming.distance}
\title{Hamming Distances of Vectors}
\usage{ hamming.distance(x, y)
}
\arguments{
\item{x}{a vector or matrix.}
\item{y}{an optional vector.}
}
\description{ If both \code{x} and
\code{y} are vectors, \code{hamming.distance} returns the Hamming
distance (number of different bytes) between this two vectors. If
\code{x} is a matrix, the Hamming distances between the rows of \code{x}
are computed and \code{y} is ignored.
}
\examples{
x <- c(1, 0, 0)
y <- c(1, 0, 1)
hamming.distance(x, y)
z <- rbind(x,y)
rownames(z) <- c("Fred", "Tom")
hamming.distance(z)
}
\keyword{multivariate}
\eof
\name{hamming.window}

\title{Computes the Coefficients of a Hamming Window.}

\usage{hamming.window(n)}

\alias{hamming.window}


\arguments{
\item{n}{The length of the window.}
}

\description{The filter coefficients \eqn{w_i}{w(i)} of a Hamming
window of length 
\code{n} are computed according to the formula
\deqn{w_i = 0.54 - 0.46 \cos\frac{2\pi i}{n-1}}{
w(i) = 0.54 - 0.46*cos(2*pi*i/(n-1))}
}

\value{A vector containing the filter coefficients.}

\references{For a definition of the Hamming window, see for example\cr
Alan V. Oppenheim and Roland W. Schafer: "Discrete-Time Signal
Processing", Prentice-Hall, 1989.}

\author{Andreas Weingessel}

\seealso{stft, hanning.window}

\examples{hamming.window(10)

x<-rnorm(500)
y<-stft(x, wtype="hamming.window")
plot(y)
}

\keyword{ts}
\eof
\name{hanning.window}

\title{Computes the Coefficients of a Hanning Window.}

\usage{hanning.window(n)}

\alias{hanning.window}


\arguments{
\item{n}{The length of the window.}
}

\description{The filter coefficients \eqn{w_i}{w(i)} of a Hanning
window of length 
\code{n} are computed according to the formula
\deqn{w_i = 0.5 - 0.5 \cos\frac{2\pi i}{n-1}}{
w(i) = 0.5 - 0.5*cos(2*pi*i/(n-1))}
}

\value{A vector containing the filter coefficients.}

\references{For a definition of the Hanning window, see for example\cr
Alan V. Oppenheim and Roland W. Schafer: "Discrete-Time Signal
Processing", Prentice-Hall, 1989.}

\author{Andreas Weingessel}

\seealso{stft, hamming.window}

\examples{hanning.window(10)

x<-rnorm(500)
y<-stft(x, wtype="hanning.window")
plot(y)
}

\keyword{ts}
\eof
\name{ica}
\alias{ica}
\alias{plot.ica}
\alias{print.ica}
\title{Independent Component Analysis}
\usage{
ica(X, lrate, epochs=100, ncomp=dim(X)[2], fun="negative")
}
\arguments{
 \item{X}{The matrix for which the ICA is to be computed}
 \item{lrate}{learning rate}
 \item{epochs}{number of iterations}
 \item{ncomp}{number of independent components}
 \item{fun}{function used for the nonlinear computation part}
}
\description{
This is an R-implementation of the Matlab-Function of
Petteri.Pajunen@hut.fi.

For a data matrix X independent components are extracted by applying a
nonlinear PCA algorithm. The parameter \code{fun} determines which
nonlinearity is used. \code{fun} can either be a function or one of the
following strings "negative kurtosis", "positive kurtosis", "4th
moment" which can be abbreviated to uniqueness. If \code{fun} equals
"negative (positive) kurtosis" the function tanh (x-tanh(x)) is used
which provides ICA for sources with negative (positive) kurtosis. For
\code{fun == "4th moments"} the signed square function is used.
}
\value{
  An object of class \code{"ica"} which is a list with components
  \item{weights}{ICA weight matrix}
  \item{projection}{Projected data}
  \item{epochs}{Number of iterations}
  \item{fun}{Name of the used function}
  \item{lrate}{Learning rate used}
  \item{initweights}{Initial weight matrix}
}

\references{
  Oja et al., ``Learning in Nonlinear Constrained Hebbian Networks'', in
  Proc. ICANN-91, pp. 385--390.

  Karhunen and Joutsensalo, ``Generalizations of Principal Component
  Analysis, Optimization Problems, and Neural Networks'', Neural Networks,
  v. 8, no. 4, pp. 549--562, 1995.
}
\note{Currently, there is no reconstruction from the ICA subspace to the
  original input space.}
\author{Andreas Weingessel}
\keyword{multivariate}
\eof
\name{impute}
\alias{impute}
\title{Replace Missing Values}
\usage{
impute(x, what="median")
}
\arguments{
 \item{x}{A matrix or dataframe.}
 \item{what}{What to impute.}
}
\description{
    Replaces missing values of a matrix or dataframe with the
    medians (\code{what="median"}) or means (\code{what="mean"}) of the
    respective columns.}
\value{
    A matrix or dataframe.
}
\author{Friedrich Leisch}
\examples{
x<- matrix(1:10, ncol=2)
x[c(1,3,7)] <- NA
print(x)
print(impute(x))
}
\keyword{manip}
\eof
\name{interpolate}
\title{Interpolate Values of Array}
\usage{
interpolate(x, a, adims=lapply(dimnames(a), as.numeric),
            method="linear")
}
\alias{interpolate}
\arguments{
 \item{x}{Matrix of values at which interpolation shall take place.}
 \item{a}{Array of arbitrary dimension.}
 \item{adims}{List of the same structure as \code{dimnames(a)}.}
 \item{method}{Interpolation method, one of \code{"linear"} or {"constant"}.}
}
\description{
  For each row in matrix \code{x}, the hypercube of \code{a} containing
  this point is searched. The corners of the hypercube are
  linearly interpolated. By default, \code{dimnames(a)} is taken to
  contain the coordinate values for each point in \code{a}. This can be
  overridden using \code{adims}. If \code{method=="constant"}, the value
  of the ``lower left'' corner of the hypercube is returned.
}
\author{Friedrich Leisch}
\seealso{\code{\link{approx}}, \code{\link{spline}}}
\examples{
x <- seq(0,3,0.2)
z <- outer(x,x, function(x,y) sin(x*y))
dimnames(z) <- list(x,x)
sin(1.1*2.1)
interpolate(c(1.1, 2.1),z)
}
\keyword{arith}
\keyword{multivariate}

\eof
\name{kurtosis}
\alias{kurtosis}
\title{Kurtosis}
\description{
  Computes the kurtosis.
}
\usage{
kurtosis(x, na.rm=FALSE)
}
\arguments{
  \item{x}{a numeric vector containing the values whose kurtosis is to
    be computed.}
  \item{na.rm}{a logical value indicating whether \code{NA} values
    should be stripped before the computation proceeds.}
}
\details{
  If \eqn{N = \mathrm{length}(x)}{N = length(x)}, then the kurtosis of
  \eqn{x} is defined as
  \deqn{N^{-1} \mathrm{sd}(x)^{-4}
    \sum_i(x_i - \mathrm{mean}(x))^4 - 3.}{
    N^(-1) sd(x)^(-4) sum_i (x_i - mean(x))^4 - 3.}
}
\value{
  The kurtosis of \code{x}.
}
\examples{
x <- rnorm(100)
kurtosis(x)
}
\keyword{univar}
\eof
\name{lca}
\alias{lca}
\alias{print.lca}
\alias{summary.lca}
\alias{print.summary.lca}
\alias{predict.lca}
\title{Latent Class Analysis (LCA)}
\usage{
lca(x, k, niter=100, matchdata=FALSE, verbose=FALSE)
}
\arguments{
 \item{x}{Either a data matrix of binary observations or a list of
     patterns as created by \code{\link{countpattern}}}
 \item{k}{Number of classes used for LCA}
 \item{niter}{Number of Iterations}
 \item{matchdata}{If \code{TRUE} and \code{x} is a data matrix, the class
     membership of every data point is returned, otherwise the class
     membership of every pattern is returned.}
 \item{verbose}{If \code{TRUE} some output is printed during the
   computations.}
}
\description{
  A latent class analysis with \code{k} classes is performed on the data
  given by \code{x}.
}
\value{
  An object of class \code{"lca"} is returned, containing
  \item{w}{Probabilities to belong to each class}
  \item{p}{Probabilities of a `1' for each variable in each class}
  \item{matching}{Depending on \code{matchdata} either the class
      membership of each pattern or of each data point}
  \item{logl, loglsat}{The LogLikelihood of the model and of the
      saturated model}
  \item{bic, bicsat}{The BIC of the model and of the
      saturated model}
  \item{chisq}{Pearson's Chisq}
  \item{lhquot}{Likelihood quotient of the model and the saturated
      model}
  \item{n}{Number of data points.}
  \item{np}{Number of free parameters.}
}

\references{Anton K. Formann: ``Die Latent-Class-Analysis'', Beltz
    Verlag 1984}

\author{Andreas Weingessel}

\seealso{
  \code{\link{countpattern}},
  \code{\link{bootstrap.lca}}
}
\examples{
## Generate a 4-dim. sample with 2 latent classes of 500 data points each.
## The probabilities for the 2 classes are given by type1 and type2.
type1 <- c(0.8,0.8,0.2,0.2)
type2 <- c(0.2,0.2,0.8,0.8)
x <- matrix(runif(4000),nr=1000)
x[1:500,] <- t(t(x[1:500,])<type1)*1
x[501:1000,] <- t(t(x[501:1000,])<type2)*1

l <- lca(x, 2, niter=5)
print(l)
summary(l)
p <- predict(l, x)
table(p, c(rep(1,500),rep(2,500)))
}
\keyword{multivariate}
\keyword{cluster}
\eof
\name{matchClasses}
\alias{matchClasses}
\alias{compareMatchedClasses}
\title{Find similar classes in two-way contingency tables}
\usage{
matchClasses(tab, method="rowmax", iter=1, maxexact=9, verbose=TRUE)
compareMatchedClasses(x, y, method="rowmax", iter=1,
                      maxexact=9, verbose=FALSE)
}
\arguments{
 \item{tab}{Two-way contingency table of class memberships}
 \item{method}{One of \code{"rowmax"}, \code{"greedy"} or
     \code{"exact"}.}
 \item{iter}{Number of iterations used in greedy search.}
 \item{verbose}{If \code{TRUE}, display some status messages during
   computation.}
 \item{maxexact}{Maximum number of variables for which all possible
   permutations are computed.}
 \item{x, y}{Vectors or matrices with class memberships.}
}
\description{
    Try to find a mapping between the two groupings, such that as many
    cases as possible are in one of the matched pairs. 
}
\details{
    If \code{method="rowmax"}, then each class defining a row in the
    contingency table is mapped to the column of the correspoding row
    maximum. Hence, some columns may be mapped to more than one row
    (while each row is mapped to a single column).

    If \code{method="greedy"} or \code{method="exact"}, then the
    contingency table must be a square matrix and a unique mapping is
    computed. This corresponds to a permutation of columns and rows,
    such that sum of the main diagonal, i.e., the trace of the matrix,
    gets as large as possible. For both methods, first all pairs where
    row and columns maxima correspond and are bigger than the sum of all
    other elements in the corresponding columns and rows together are
    located and fixed (this is a necessary condition for maximal trace).

    If \code{method="exact"}, then for the remaining rows and columns,
    all possible permutations are computed and the optimum is
    returned. This can get computationally infeasible very fast. If more
    than \code{maxexact} rows and columns remain after applying the
    necessary condition, then \code{method} is reset to \code{"greedy"}. If
    \code{method="greedy"}, then a greedy heuristic is tried \code{iter}
    times. Repeatedly a row is picked at random and matched to the free
    column with the maximum value.

    \code{compareMatchedClasses()} computes the contingency table for
    each combination of columns from \code{x} and \code{y} and applies
    \code{matchClasses} to that table. The columns of the table are
    permuted accordingly and then the table is
    passed to \code{\link{classAgreement}}. The resulting agreement
    coefficients (diag, kappa, \ldots) are returned. The return value of
    \code{compareMatchedClasses()} is a list containing a matrix for
    each coefficient; with element (k,l) corresponding to the k-th
    column of \code{x} and l-th column of \code{y}. If \code{y} is
    missing, then the columns of \code{x} are compared with each other.
}
\author{Friedrich Leisch}
\seealso{\code{\link{classAgreement}}}
\examples{
## a stupid example with no class correlations:
g1 <- sample(1:5, size=1000, replace=TRUE)
g2 <- sample(1:5, size=1000, replace=TRUE)
tab <- table(g1, g2)
matchClasses(tab, "exact")

## let pairs (g1=1,g2=4) and (g1=3,g2=1) agree better
k <- sample(1:1000, size=200)
g1[k] <- 1
g2[k] <- 4

k <- sample(1:1000, size=200)
g1[k] <- 3
g2[k] <- 1

tab <- table(g1, g2)
matchClasses(tab, "exact")

## get agreement coefficients:
compareMatchedClasses(g1, g2, method="exact")
}
\keyword{category}
\eof
\name{moment}
\alias{moment}
\title{Statistical Moment}
\description{
  Computes the (optionally centered and/or absolute) sample moment of a
  certain order.
}
\usage{
moment(x, order=1, center=FALSE, absolute=FALSE, na.rm=FALSE)
}
\arguments{
 \item{x}{a numeric vector containing the values whose moment is to be
   computed.}
 \item{order}{order of the moment to be computed, the default is to
   compute the first moment, i.e., the mean.}
 \item{center}{a logical value indicating whether centered moments are
   to be computed.}
 \item{absolute}{a logical value indicating whether absolute moments are
   to be computed.}
 \item{na.rm}{a logical value indicating whether \code{NA} values
   should be stripped before the computation proceeds.}
}
\details{
  When \code{center} and \code{absolute} are both \code{FALSE}, the
  moment is simply \code{sum(x ^ order) / length(x)}.
}
\author{Kurt Hornik and Friedrich Leisch}
\seealso{
  \code{\link{mean}},
  \code{\link{var}}}
\examples{
x <- rnorm(100)

## Compute the mean
moment(x)
## Compute the 2nd centered moment (!= var)
moment(x, order=2, center=TRUE)

## Compute the 3rd absolute centered moment
moment(x, order=3, center=TRUE, absolute=TRUE)
}
\keyword{univar}
\eof
\name{naiveBayes}
\alias{naiveBayes}
\alias{print.naiveBayes}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Naive Bayes Classifier}
\description{
  Computes the conditional a-posterior probabilities of a categorical
  class variable given independent categorical predictor variables using
  the Bayes rule.
}
\usage{
naiveBayes(formula, data, ..., subset, na.action = na.pass)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{formula}{A formula of the form \code{class ~ x1 + x2 +
      \dots}. Interactions are not allowed.}
  \item{data}{Either a data frame of factors or a contingency table.}
  \item{\dots}{Currently not used.}
  \item{subset}{For data given in a data frame, an index vector
    specifying the cases to be used in the
    training sample.  (NOTE: If given, this argument must be
    named.)}
  \item{na.action}{A function to specify the action to be taken if \code{NA}s are
          found. The default action is not to count them for the
	  computation of the probability factors. An
          alternative is na.omit, which leads to rejection of cases
          with missing values on any required variable.  (NOTE: If
          given, this argument must be named.)}
}
\value{
  An object of class \code{"naiveBayes"} including components:

  \item{apriori}{Class distribution for the dependent variable.}
  \item{tables}{A list of probability tables,
    one for each predictor variable, giving, for each attribute level, the conditional
    probabilities given the predictor classes.}

}
\author{David Meyer \email{david.meyer@ci.tuwien.ac.at}}
\seealso{\code{\link{predict.naiveBayes}}}
\examples{
data(HouseVotes84)
model <- naiveBayes(Class ~ ., data = HouseVotes84)
predict(model, HouseVotes84[1:10,-1])
predict(model, HouseVotes84[1:10,-1], type = "raw")

pred <- predict(model, HouseVotes84[,-1])
table(pred, HouseVotes84$Class)

data(Titanic)
m <- naiveBayes(Survived ~ ., data = Titanic)
m
predict(m, as.data.frame(Titanic)[,1:3])

}
\keyword{classif}% at least one, from doc/KEYWORDS
\keyword{category}% at least one, from doc/KEYWORDS

\eof
\name{permutations}
\alias{permutations}
\title{All permutations of integers 1:n}
\description{
  Returns a matrix containing all permutations of the integers
  \code{1:n} (one permutation per row).
}
\usage{
permutations(n)
}
\arguments{
  \item{n}{Number of element to permute.}
}
\author{Friedrich Leisch}
\examples{
permutations(3)
}
\keyword{datagen}
\eof
\name{plot.stft}
\alias{plot.stft}
\title{Plot Short Time Fourier Transforms}
\description{
  An object of class \code{"stft"} is plotted as a gray scale image.
  The x-axis corresponds to time, the y-axis to frequency.  If the
  default colormap is used, dark regions in the plot correspond to high
  values at the particular time/frequency location.
}
\usage{
\method{plot}{stft}(x, col = gray(63:0/63), \dots)
}
\arguments{
  \item{x}{An object of class \code{"stft"} as obtained by the function
    \code{stft}.}
  \item{col}{An optional colormap.  By default 64 gray values are used,
    where white corresponds to the minimum value and black to the
    maximum.}
  \item{\dots}{further arguments to be passed to or from methods.}
}
\value{No return value. This function is only for plotting.}
\author{Andreas Weingessel}
\seealso{stft}
\examples{x<-rnorm(500)
y<-stft(x)
plot(y)
}
\keyword{ts}
\eof
\name{plot.svm}
\alias{plot.svm}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Plot svm objects}
\description{
  Generates a scatter plot of the input data of a \code{svm} fit for
  classification models by highlighting the classes and support
  vectorts. Optionally, draws filled contour plot of the class regions.
}
\usage{
plot.svm(x, data, formula, fill = TRUE, grid = 50, slice = list(), ...)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{x}{An object of class \code{svm}}
  \item{data}{data to visualize. Should be the same used for fitting.}
  \item{formula}{formula selecting the visualized two dimensions. Only
    needed if more than two input variables are used.}
  \item{fill}{switch indicating whether a contour plot for the class
    regions should be added.}
  \item{grid}{granularity for the contour plot.}
  \item{slice}{a list of named numeric values for the dimensions held
    constant (only needed if more than two variables are
    used). Dimensions not specified are fixed at 0.}
  \item{\dots}{additional graphics parameters passed to
    \code{filled.contour} and \code{plot}.}
}

\author{David Meyer\cr
  \email{david.meyer@ci.tuwien.ac.at}}
\seealso{\code{\link{svm}}}

\examples{
## a simple example
library(MASS)
data(cats)
m <- svm(Sex~., data = cats)
plot(m, cats)

## more than two variables: fix 2 dimensions
data(iris)
m2 <- svm(Species~., data = iris)
plot(m2, iris, Petal.Width ~ Petal.Length,
     slice = list(Sepal.Width = 3, Sepal.Length = 4))
}
\keyword{neural}% at least one, from doc/KEYWORDS
\keyword{classif}% __ONLY ONE__ keyword per line
\keyword{nonlinear}% __ONLY ONE__ keyword per line
\eof
\name{plot.tune}
\alias{plot.tune}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Plot tuning object}
\description{
  Visualizes the results of parameter tuning.
}
\usage{
plot.tune(x, type = c("contour", "perspective"), theta = 60,
          col = "lightblue", main = NULL, xlab = NULL, ylab = NULL,
          swapxy = FALSE, transform.x = NULL, transform.y = NULL,
          transform.z = NULL, color.palette = topo.colors,
          nlevels = 20, ...)

}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{x}{an object of class \code{tune}}
  \item{type}{choose whether a contour plot or a perspective plot is
    used if two parameters are to be visualized. Ignored if only one
    parameter has been tuned.}
  \item{theta}{angle of azimuthal direction.}
  \item{col}{the color(s) of the surface facets.  Transparent colours are
          ignored.}
  \item{main}{main title}
  \item{xlab, ylab}{titles for the axes.  N.B. These must be character
          strings; expressions are not accepted.  Numbers will be
          coerced to character strings.}
  \item{swapxy}{if \code{TRUE}, the parameter axes are swaped (only used
    in case of two parameters).}
  \item{transform.x, transform.y, transform.z}{functions to transform
    the parameters (\code{x} and \code{y}) and the error measures
    (\code{z}). Ignored if \code{NULL}.}
  \item{color.palette}{color palette used in contour plot.}
  \item{nlevels}{number of levels used in contour plot.}
  \item{\dots}{Further graphics parameters.}
}
\author{
  David Meyer (based on C/C++-code by Chih-Chung Chang and Chih-Jen Lin)\cr
  \email{david.meyer@ci.tuwien.ac.at}
}
\seealso{\code{\link{tune}}}

\examples{
  data(iris)
  obj <- tune.svm(Species~., data = iris, sampling = "fix",
                  gamma = 2^c(-8,-4,0,4), cost = 2^c(-8,-4,-2,0))
  plot(obj, transform.x = log2, transform.y = log2)
  plot(obj, type = "perspective", theta = 120, phi = 45)
}
\keyword{models}% __ONLY ONE__ keyword per line
\eof
\name{predict.naiveBayes}
\alias{predict.naiveBayes}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Naive Bayes Classifier}
\description{
  Computes the conditional a-posterior probabilities of a categorical
  class variable given independent categorical predictor variables using
  the Bayes rule.
}
\usage{
predict.naiveBayes(object, newdata, type = c("class", "raw"), threshold = 0.001, ...)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{object}{An object of class \code{"naiveBayes"}.}
  \item{newdata}{A dataframe with new predictors.}
  \item{type}{see value.}
  \item{threshold}{Value replacing cells with 0 probabilities.}
  \item{\dots}{Currently not used.}
}
\value{
If \code{type = "raw"}, the conditional a-posterior
probabilities for each class are returned, and the class with
maximal probability else.
}
\details{
 For attributes with missing values, the
corresponding conditional probabilities are omitted for prediction.
}
\author{David Meyer \email{david.meyer@ci.tuwien.ac.at}}
\seealso{\code{\link{naiveBayes}}}
\examples{
data(HouseVotes84)
model <- naiveBayes(Class ~ ., data = HouseVotes84)
predict(model, HouseVotes84[1:10,-1])
predict(model, HouseVotes84[1:10,-1], type = "raw")

pred <- predict(model, HouseVotes84[,-1])
table(pred, HouseVotes84$Class)

data(Titanic)
m <- naiveBayes(Survived ~ ., data = Titanic)
m
predict(m, as.data.frame(Titanic)[,1:3])
}
\keyword{classif}% at least one, from doc/KEYWORDS
\keyword{category}% at least one, from doc/KEYWORDS
\eof
\name{predict.svm}
\alias{predict.svm}
\title{Predict method for Support Vector Machines}
\description{
  This function predicts values based upon a model trained by \code{svm}.
}
\usage{
\method{predict}{svm}(object, newdata, ..., na.action = na.omit)
}

\arguments{
  \item{object}{Object of class \code{"svm"}, created by \code{svm}.}
  \item{newdata}{A matrix containing the new input data. A vector will
    be transformed to a n x 1 matrix.}
  \item{na.action}{A function to specify the action to be taken if `NA's are
    found. The default action is \code{na.omit}, which leads to rejection of cases
    with missing values on any required variable. An alternative
    is \code{na.fail}, which causes an error if \code{NA} cases
    are found. (NOTE: If given, this argument must be named.)}	
  \item{\dots}{Currently not used.}
}
\value{
  The predicted value (for classification: the label, for density
  estimation: \code{TRUE} or \code{FALSE}).
}
\note{
  If the training set was scaled by \code{svm} (done by default), the
  new data is scaled accordingly using scale and center of
  the training data.
}
\references{
  \itemize{
    \item
      Chang, Chih-Chung and Lin, Chih-Jen:\cr
      \emph{LIBSVM 2.0: Solving Different Support Vector Formulations.}\cr
      \url{http://www.csie.ntu.edu.tw/~cjlin/papers/libsvm2.ps.gz}
    
    \item 
      Chang, Chih-Chung and Lin, Chih-Jen:\cr
      \emph{Libsvm: Introduction and Benchmarks}\cr
      \url{http://www.csie.ntu.edu.tw/~cjlin/papers/q2.ps.gz}
    
  }
}
\author{
  David Meyer (based on C++-code by Chih-Chung Chang and Chih-Jen Lin)\cr
  \email{david.meyer@ci.tuwien.ac.at}
}
\seealso{
  \code{\link{svm}}
}
\examples{
data(iris)
attach(iris)

## classification mode
# default with factor response:
model <- svm (Species~., data=iris)

# alternatively the traditional interface:
x <- subset (iris, select = -Species)
y <- Species
model <- svm (x, y) 

print (model)
summary (model)

# test with train data
pred <- predict (model, x)
# (same as:)
pred <- predict (model)

# Check accuracy:
table (pred,y)

## try regression mode on two dimensions

# create data
x <- seq (0.1,5,by=0.05)
y <- log(x) + rnorm (x, sd=0.2)

# estimate model and predict input values
m   <- svm (x,y)
new <- predict (m,x)

# visualize
plot   (x,y)
points (x, log(x), col=2)
points (x, new, col=4)

## density-estimation

# create 2-dim. normal with rho=0:
X <- data.frame (a=rnorm (1000), b=rnorm (1000))
attach (X)

# traditional way:
m <- svm (X, gamma=0.1)

# formula interface:
m <- svm (~., data=X, gamma=0.1)
# or:
m <- svm (~a+b, gamma=0.1)

# test:
newdata <- data.frame(a=c(0,4), b=c(0,4))
predict (m, newdata)
}
\keyword{neural}
\keyword{nonlinear}
\keyword{classif}

\eof
\name{rbridge}
\alias{rbridge}
\title{Simulation of Brownian Bridge}
\usage{
rbridge(end = 1, frequency = 1000)
}
\arguments{
\item{end}{the time of the last observation.}
\item{frequency}{the number of observations per unit of time.}
}
\description{
\code{rwiener} returns a time series containing a simulated realization
of the Brownian bridge on the interval [0,\code{end}]. If W(t) is a
Wiener process, then the Brownian bridge is defined as W(t) - t W(1).
}
\seealso{
rwiener
}
\examples{
# simulate a Brownian bridge on [0,1] and plot it

x <- rbridge()
plot(x,type="l")
}
\keyword{distribution}
\eof
\name{read.matrix.csr}
\alias{read.matrix.csr}
\alias{write.matrix.csr}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{read/write sparse data}
\description{
  reads and writes a file in sparse data format.
}
\usage{
read.matrix.csr(file, fac = TRUE, ncol = NULL)
write.matrix.csr(x, file = "out.dat", y = NULL)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{x}{An object of class \code{matrix.csr}}
  \item{y}{A vector (either numeric or a factor)}
  \item{file}{The filename.}
  \item{fac}{If \code{TRUE} and y-values are stored in the file, the
    values are interpreted as factor levels.}
  \item{ncol}{Number of columns, detected automatically. Can be used to
    add empty columns (these are not stored in the sparse format).}
}
\value{
  If the data file includes no y variable, \code{read.matrix.csr} returns an object of class
  \code{matrix.csr}, else a list with components:
  \item{x}{object of class \code{matrix.csr}}
  \item{y}{vector of numeric values or factor levels, depending on \code{fac}.}
}
\author{
  David Meyer (based on C/C++-code by Chih-Chung Chang and Chih-Jen Lin)\cr
  \email{david.meyer@ci.tuwien.ac.at}
}
\seealso{\code{\link[SparseM]{matrix.csr}}}

\examples{
\dontrun{
  library(methods)
  if (require(SparseM)) {
    data(iris)
    x <- as.matrix(iris[,1:4])
    y <- iris[,5]
    xs <- as.matrix.csr(x)
    write.matrix.csr(xs, y = y, file="iris.dat")
    xs2 <- read.matrix.csr("iris.dat")$x
    if (!all(as.matrix(xs) == as.matrix(xs2)))
      stop("Error: objects are not equal!")
  }
}
}
\keyword{IO}% at least one, from doc/KEYWORDS
\eof
\name{read.octave}
\alias{read.octave}
\title{Read Octave Data File}
\description{
  Read a vector or matrix from an Octave ASCII data file created using
  the command \code{save -ascii} in Octave.
}
\usage{
read.octave(file, quiet=FALSE)
}
\arguments{
  \item{file}{the name of a Octave data file to read.}
  \item{quiet}{do not print information on type and size of the object
    read in.}
}
\details{
  \code{read.octave} reads only the first object found in the file and
  ignores the rest.
}
\value{
  \code{read.octave} returns an object of type vector or matrix.
}
\seealso{
  \code{\link{scan}},
  \code{\link{read.table}}
}
\keyword{file}
\eof
\name{rectangle.window}
\title{Computes the Coefficients of a Rectangle Window.}

\usage{rectangle.window(n)}

\alias{rectangle.window}


\arguments{
\item{n}{The length of the window.}
}

\description{Returns the filter coefficents of a rectangle
window. That is a vector of \code{n} 1.

The purpose of this function is just to have a name for the R command
\code{rep (1, n)}. 
}

\value{A vector of length \code{n} filled with 1.}

\author{Andreas Weingessel}

\seealso{stft}

\examples{x<-rnorm(500)
y<-stft(x, wtype="rectangle.window")
plot(y)
}

\keyword{ts}
\eof
\name{rwiener}
\alias{rwiener}
\title{Simulation of Wiener Process}
\usage{
rwiener(end = 1, frequency = 1000)
}
\arguments{
\item{end}{the time of the last observation.}
\item{frequency}{the number of observations per unit of time.}
}
\description{
\code{rwiener} returns a time series containing a simulated realization
of the Wiener process on the interval [0,\code{end}]
}
\examples{
# simulate a Wiener process on [0,1] and plot it

x <- rwiener()
plot(x,type="l")
}
\keyword{distribution}
\eof
\name{allShortestPaths}
\alias{allShortestPaths}
\alias{extractPath}
\title{Find Shortest Paths Between All Nodes in a Directed Graph}
\description{
  \code{allShortestPaths} finds all shortest paths in a directed (or
  undirected) graph using Floyd's algorithm. \code{extractPath} can be
  used to actually extract the path between a given pair of nodes.
}
\usage{
allShortestPaths(x)
extractPath(obj, start, end)
}
\arguments{
  \item{x}{matrix or distance object}
  \item{obj}{return value of \code{allShortestPaths}}
  \item{start}{integer, starting point of path}
  \item{end}{integer, end point of path}
}
\details{
  If \code{x} is a matrix, then \code{x[i,j]} has to be the length of the
  direct path from point \code{i} to point \code{j}. If no direct
  connection from point \code{i} to point \code{j} exist, then
  \code{x[i,j]} should be either \code{NA} or \code{Inf}. Note that the
  graph can be directed, hence \code{x[i,j]} need not be the same as
  \code{x[j,i]}. The main diagonal of \code{x} is ignored.
  Alternatively, \code{x} can be a distance object as returned by
  \code{\link{dist}} (corresponding to an undirected graph).
}
\value{
  \code{allShortestPaths} returns a list with components
  \item{length}{A matrix with the total lengths of the shortest
    path between each pair of points.}
  \item{middlePoints}{A matrix giving a point in the middle of each
    shortest path (or 0 if the direct connection is the shortest path),
    this is mainly used as input for \code{extractPath}.}
  \code{extractPath} returns a vector of node numbers giving with the
  shortest path between two points.
}
\references{Kumar, V., Grama, A., Gupta, A. and Karypis, G. Introduction
  to Parallel Programming - Design and Analysis of
  Algorithms, Benjamin Cummings Publishing, 1994, ISBN 0-8053-3170-0}
\author{Friedrich Leisch}
\examples{
## build a graph with 5 nodes
x <- matrix(NA, 5, 5)
diag(x) <- 0
x[1,2] <- 30; x[1,3] <- 10
x[2,4] <- 70; x[2,5] <- 40
x[3,4] <- 50; x[3,5] <- 20
x[4,5] <- 60
x[5,4] <- 10
print(x)

## compute all path lengths
z <- allShortestPaths(x)
print(z)

## the following should give 1 -> 3 -> 5 -> 4
extractPath(z, 1, 4)
}
\keyword{optimize}
\eof
\name{sigmoid}
\alias{sigmoid}
\alias{dsigmoid}
\alias{d2sigmoid}
\title{The logistic function and derivatives}
\description{
  Sigmoid \eqn{1/(1 + \exp(-x))}{1/(1 + exp(-x))}, first and second
  derivative.}
\usage{
sigmoid(x)
dsigmoid(x)
d2sigmoid(x)
}
\arguments{
  \item{x}{a numeric vector}
}
\author{Friedrich Leisch}
\examples{
plot(sigmoid, -5, 5, ylim = c(-.2, 1))
plot(dsigmoid, -5, 5, add = TRUE, col = 2)
plot(d2sigmoid, -5, 5, add = TRUE, col = 3)
}
\keyword{math}

\eof
\name{skewness}
\alias{skewness}
\title{Skewness}
\description{
  Computes the skewness.
}
\usage{
skewness(x, na.rm=FALSE)
}
\arguments{
  \item{x}{a numeric vector containing the values whose skewness is to
    be computed.}
  \item{na.rm}{a logical value indicating whether \code{NA} values
    should be stripped before the computation proceeds.}
}
\details{
  If \eqn{N = \mathrm{length}(x)}{N = length(x)}, then the skewness of
  \eqn{x} is defined as 
  \deqn{N^{-1} \mathrm{sd}(x)^{-3} \sum_i (x_i - \mathrm{mean}(x))^3.}{
    N^(-1) sd(x)^(-3) sum_i (x_i - mean(x))^3.}
}
\value{
  The skewness of \code{x}.
}
\examples{
x <- rnorm(100)
skewness(x)
}
\keyword{univar}
\eof
\name{stft}
\title{Computes the Short Time Fourier Transform of a Vector}

\usage{stft(X, win=min(80,floor(length(X)/10)), inc=min(24,
floor(length(X)/30)), coef=64, wtype="hanning")}  
\alias{stft}

\arguments{
\item{X}{The vector from which the stft is computed.}
\item{win}{Length of the window. For long vectors the default window
size is 80, for short vectors the window size is chosen so that 10
windows fit in the vector.}
\item{inc}{Increment by which the window is shifted. For long vectors
the default increment is 24, for short vectors the increment is chosen
so that 30 increments fit in the vector.} 
\item{coef}{Number of Fourier coefficients}
\item{wtype}{Type of window used}
}

\description{This function computes the Short Time Fourier Transform
of a given vector \code{X}. 

First, time-slices of length \code{win} are
extracted from the vector. The shift of one time-slice to the next one is
given by \code{inc}. The values of these time-slices are smoothed by
mulitplying them with a window function specified in \code{wtype}. For
the thus obtained windows, the Fast Fourier Transform is computed.}

\value{Object of type stft. Contains the values of the stft and
information about the parameters. 

\item{values}{A matrix containing the results of the stft. Each row of
the matrix contains the \code{coef} Fourier coefficients of one
window.} 
\item{windowsize}{The value of the parameter \code{win}}
\item{increment}{The value of the parameter \code{inc}}
\item{windowtype}{The value of the parameter \code{wtype}}
}

\author{Andreas Weingessel}

\seealso{plot.stft}

\examples{x<-rnorm(500)
y<-stft(x)
plot(y)
}

\keyword{ts}

\eof
\name{svm}
\alias{svm}
\alias{svm.default}
\alias{svm.formula}
\alias{summary.svm}
\alias{print.summary.svm}
\alias{print.svm}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Support Vector Machines}
\description{
\code{svm} is used to train a support vector machine. It can be used to carry
out general regression and classification (of nu and epsilon-type), as
well as density-estimation. A formula interface is provided.
}
\usage{
\method{svm}{formula}(formula, data = list(), ..., subset, na.action =
na.omit, scale = TRUE)
\method{svm}{default}(x, y = NULL, scale = TRUE, type = NULL, kernel =
"radial", degree = 3, gamma = 1 / dim(x)[2], coef0 = 0, cost = 1, nu = 0.5,
class.weights = NULL, cachesize = 40, tolerance = 0.001, epsilon = 0.5,
shrinking = TRUE, cross = 0, fitted = TRUE, ..., subset, na.action = na.omit)
}
\arguments{
  \item{formula}{a symbolic description of the model to be fit. Note, that an
          intercept is always included, whether given in the formula or
          not.}
  \item{data}{an optional data frame containing the variables in the model.
          By default the variables are taken from the environment which
          `svm' is called from.}
  \item{x}{a data matrix, a vector, or a sparse matrix (object of class
    \code{\link[SparseM]{matrix.csr}} as provided by the package \code{SparseM}).}
  \item{y}{a response vector with one label for each row/component of \code{x}. Can be either
    a factor (for classification tasks) or a numeric vector (for
    regression).}
  \item{scale}{A logical vector indicating the variables to be
    scaled. If \code{scale} is of length 1, the value is recycled as
    many times as needed.
    Per default, data are scaled internally (both \code{x} and \code{y}
    variables) to zero mean and unit variance. The center and scale
    values are returned and used for later predictions.}
  \item{type}{\code{svm} can be used as a classification
    machine, as a regresson machine, or for novelty detection.
    Depending of whether \code{y} is
    a factor or not, the default setting for \code{type} is \code{C-classification} or \code{eps-regression}, respectively, but may be overwritten by setting an explicit value.\cr
    Valid options are:
    \itemize{
      \item \code{C-classification}
      \item \code{nu-classification}
      \item \code{one-classification} (for novelty detection)
      \item \code{eps-regression}
      \item \code{nu-regression}
    }
  }
  \item{kernel}{the kernel used in training and predicting. You
    might consider changing some of the following parameters, depending
    on the kernel type.\cr
    \describe{
      \item{linear:}{\eqn{u'v}{u'*v}}
      \item{polynomial:}{\eqn{(\gamma u'v + coef0)^{degree}}{(gamma*u'*v + coef0)^degree}}
      \item{radial basis:}{\eqn{e^(-\gamma |u-v|^2)}{exp(-gamma*|u-v|^2)}}
      \item{sigmoid:}{\eqn{tanh(\gamma u'v + coef0)}{tanh(gamma*u'*v + coef0)}}
      }
    }
  \item{degree}{parameter needed for kernel of type \code{polynomial} (default: 3)}
  \item{gamma}{parameter needed for all kernels except \code{linear}
    (default: 1/(data dimension))}
  \item{coef0}{parameter needed for kernels of type \code{polynomial}
    and \code{sigmoid} (default: 0)}
  \item{cost}{cost of constraints violation (default: 1)---it is the
    `C'-constant of the regularization term in the Lagrange formulation.}
  \item{nu}{parameter needed for \code{nu-classification} and \code{one-classification}}
  \item{class.weights}{a named vector of weights for the different
    classes, used for asymetric class sizes. Not all factor levels have
    to be supplied (default weight: 1). All components have to be named.}
  \item{cachesize}{cache memory in MB (default 40)}
  \item{tolerance}{tolerance of termination criterion (default: 0.001)}
  \item{epsilon}{epsilon in the insensitive-loss function (default: 0.5)}
  \item{shrinking}{option whether to use the shrinking-heuristics
    (default: \code{TRUE})}
  \item{cross}{if a integer value k>0 is specified, a k-fold cross
    validation on the training data is performed to assess the quality
    of the model: the accuracy rate for classification and the Mean
    Sqared Error for regression}
  \item{fitted}{indicates whether the fitted values should be computed
    and included in the model or not (default: \code{TRUE})}
  \item{\dots}{additional parameters for the low level fitting function
    \code{svm.default}}
  \item{subset}{An index vector specifying the cases to be used in the
          training sample.  (NOTE: If given, this argument must be
          named.)}
  \item{na.action}{A function to specify the action to be taken if \code{NA}s are
          found. The default action is \code{na.omit}, which leads to rejection of cases
          with missing values on any required variable. An alternative
	  is \code{na.fail}, which causes an error if \code{NA} cases
	  are found. (NOTE: If given, this argument must be named.)}	
}

\value{
  An object of class \code{"svm"} containing the fitted model, including:
  \item{SV}{The resulting support vectors (possibly scaled).}
  \item{index}{The index of the resulting support vectors in the data
    matrix. Note that this index refers to the preprocessed data (after
    the possible effect of \code{na.omit} and \code{subset})}
  \item{coefs}{The corresponding coefficients times the training labels.}
  \item{rho}{The negative intercept.}
}
\details{For multiclass-classification with k levels, k>2, \code{libsvm} uses the
  `one-against-one'-approach, in which k(k-1)/2 binary classifiers are
  trained; the appropriate class is found by a voting scheme.\cr
\code{libsvm} internally uses a sparse data representation, which is 
also high-level supported by the package \code{SparseM}.\cr
If the predictor variables include factors, the formula interface must be used to get a
correct model matrix. \code{plot.svm} allows a simple graphical
visualization of classification models.}
\note{Data are scaled internally, usually yielding better results.}
\references{
  \itemize{
    \item
      Chang, Chih-Chung and Lin, Chih-Jen:\cr
      \emph{LIBSVM: a library for Support Vector Machines}\cr
      \url{http://www.csie.ntu.edu.tw/~cjlin/libsvm}

     \item
      Exact formulations of models, algorithms, etc. can be found in the
      document:\cr
      Chang, Chih-Chung and Lin, Chih-Jen:\cr
      \emph{LIBSVM: a library for Support Vector Machines}\cr
      \url{http://www.csie.ntu.edu.tw/~cjlin/papers/libsvm.ps.gz}
    
    \item 
      Chang, Chih-Chung and Lin, Chih-Jen:\cr
      \emph{Libsvm: Introduction and Benchmarks}\cr
      \url{http://www.csie.ntu.edu.tw/~cjlin/papers/q2.ps.gz}
    
  }
}
\author{
  David Meyer (based on C/C++-code by Chih-Chung Chang and Chih-Jen Lin)\cr
  \email{david.meyer@ci.tuwien.ac.at}
}
\seealso{
  \code{\link{predict.svm}}
  \code{\link{plot.svm}}
  \code{\link[SparseM]{matrix.csr}} (in package `SparseM')
}
\examples{
data(iris)
attach(iris)

## classification mode
# default with factor response:
model <- svm(Species~., data=iris)

# alternatively the traditional interface:
x <- subset(iris, select = -Species)
y <- Species
model <- svm(x, y) 

print(model)
summary(model)

# test with train data
pred <- predict(model, x)

# Check accuracy:
table(pred, y)

## try regression mode on two dimensions

# create data
x <- seq(0.1, 5, by = 0.05)
y <- log(x) + rnorm(x, sd = 0.2)

# estimate model and predict input values
m   <- svm(x, y)
new <- predict(m, x)

# visualize
plot(x, y)
points(x, log(x), col = 2)
points(x, new, col = 4)

## density-estimation

# create 2-dim. normal with rho=0:
X <- data.frame(a = rnorm(1000), b = rnorm(1000))
attach(X)

# traditional way:
m <- svm(X, gamma = 0.1)

# formula interface:
m <- svm(~., data = X, gamma = 0.1)
# or:
m <- svm(~ a + b, gamma = 0.1)

# test:
newdata <- data.frame(a = c(0,4), b = c(0,4))
newdata
predict(m, newdata)

# visualization:
plot(as.matrix(X))
points(as.matrix(X)[m$index,], col = 2)
}
\keyword{neural}
\keyword{nonlinear}
\keyword{classif}









\eof
\name{tune}
\alias{tune}
\alias{print.tune}
\alias{summary.tune}
\alias{print.summary.tune}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Parameter tuning of fuctions using grid search}
\description{
  This generic function tunes hyperparameters of statistical methods
  using a grid search over supplied parameter ranges.
}
\usage{
tune(method, train.x, train.y = NULL, data = list(), validation.x =
     NULL, validation.y = NULL, ranges = NULL, predict.func = predict,
     control = tune.control(), ...)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{method}{function to be tuned.}
  \item{train.x}{either a formula or a matrix of predictors.}
  \item{train.y}{the response variable if \code{train.x} is a predictor
    matrix. Ignored if \code{train.x} is a formula.}
  \item{data}{data, if a formula interface is used. Ignored, if
    predictor matrix and response are supplied directly.}
  \item{validation.x}{an optional validation set. Depending on whether a
    formula interface is used or not, the response can be
    included in \code{validation.x} or separately speciefied using \code{validation.y}.}
  \item{validation.y}{if no formula interface is used, the response of
    the (optional) validation set.}
  \item{ranges}{a named list of parameter vectors spanning the sampling
    space. The vectors will usually be created by \code{seq}.}
  \item{predict.func}{optional predict function, if the standard \code{predict}
    behaviour is inadequate.}
  \item{control}{object of class \code{"tune.control"}, as created by the
    function \code{tune.control()}.}
  \item{\dots}{Further parameters passed to the training functions.}
}
\value{
  An object of class \code{tune}, including the components:
  \item{best.parameters}{a 1 x k data frame, k number of parameters.}
  \item{best.performance}{best achieved performance.}
  \item{performances}{if requested, a data frame of all parameter
    combinations along with the corresponding performance results.}
  \item{if requested, the model trained on the complete training data
    using the best parameter combination.}
}
\details{
  As performance measure, the classification error is used
  for classification, and the mean squared error for regression. It is
  possible to specify only one parameter combination (i.e., vectors of
  length 1) to obtain an error estimation of the specified type
  (bootstrap, cross-classification, etc.) on the given data set. For
  conveneince, there
  are several \code{tune.foo()} wrappers defined, e.g., for
  \code{nnet()}, \code{randomForest()},
  \code{rpart()}, \code{svm()}, and \code{knn()}.
}
\author{
  David Meyer\cr
  \email{david.meyer@ci.tuwien.ac.at}
}
\seealso{\code{\link{tune.control}}, \code{\link{plot.tune}},
  \code{\link{tune.svm}}, \link{tune.wrapper}}
\examples{
  data(iris)
  ## tune `svm' for classification with RBF-kernel (default in svm),
  ## using one split for training/validation set
  
  obj <- tune(svm, Species~., data = iris, 
              ranges = list(gamma = 2^(-1:1), cost = 2^(2:4)),
              control = tune.control(sampling = "fix")
             )

  ## alternatively:
  ## obj <- tune.svm(Species~., data = iris, gamma = 2^(-1:1), cost = 2^(2:4))

  summary(obj)
  plot(obj)

  ## tune `knn' using a convenience function; this time with the
  ## conventional interface and bootstrap sampling:
  x <- iris[,-5]
  y <- iris[,5]
  obj2 <- tune.knn(x, y, k = 1:5, control = tune.control(sampling = "boot"))
  summary(obj2)
  plot(obj2)

  ## tune `rpart' for regression, using 10-fold cross validation (default)
  data(mtcars)
  obj3 <- tune.rpart(mpg~., data = mtcars, minsplit = c(5,10,15))
  summary(obj3)
  plot(obj3)

  ## simple error estimation for lm using 10-fold cross validation
  tune(lm, mpg~., data = mtcars)
}
\keyword{models}% at least one, from doc/KEYWORDS

\eof
\name{tune.control}
\alias{tune.control}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{control parameters for the tune function}
\description{
  Creates an object of class \code{tune.control} to be used with
  the \code{tune} function, containing various control parameters.
}
\usage{
tune.control(random = FALSE, nrepeat = 1, repeat.aggregate = min,
sampling = c("cross", "fix", "bootstrap"), sampling.aggregate = mean,
cross = 10, fix = 2/3, nboot = 10, boot.size = 9/10, best.model = TRUE,
performances = TRUE)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{random}{if an integer value is specified, \code{random}
    parameter vectors are drawn from the parameter space.}
  \item{nrepeat}{specifies how often training shall be repeated.}
  \item{repeat.aggregate}{function for aggregating the repeated training results.}
  \item{sampling}{sampling scheme. If \code{sampling = "cross"}, a
    \code{cross}-times cross validation is performed. If \code{sampling
      = "boot"}, \code{nboot} training sets of size \code{boot.size} (part)
    are sampled from the supplied data. If \code{sampling
      = "fix"}, a single split into training/validation set is
    used, the training set containing a \code{fix} part of the supplied
    data. Note that a separate validation set can be supplied via
    \code{validation.x} and \code{validation.y}. It is only used for
    \code{sampling = "boot"} and \code{sampling = "fix"}; in the latter
    case, \code{fix} is set to 1.}
  \item{sampling.aggregate}{function for aggregating the training
    results on the generated training samples.}
  \item{cross}{number of partitions for cross-validation.}
  \item{fix}{part of the data used for training in fixed sampling.}
  \item{nboot}{number of bootstrap replications.}
  \item{boot.size}{size of the bootstrap samples.}
  \item{best.model}{if \code{TRUE}, the best model is trained and
    returned (the best parameter set is used for
    training on the complete training set).}
  \item{performances}{if \code{TRUE}, the performance results for all
    parameter combinations are returned.}
}
\value{
  An object of class \code{"tune.control"} containing all the above
  parameters (either the defaults or the user specified values).
}
\author{
  David Meyer\cr
  \email{david.meyer@ci.tuwien.ac.at}
}
\seealso{\code{\link{tune}}}
\keyword{models}% at least one, from doc/KEYWORDS
\eof
\name{tune.wrapper}
\alias{tune.wrapper}
\alias{rpart.wrapper}
\alias{tune.rpart}
\alias{best.rpart}
\alias{tune.svm}
\alias{best.svm}
\alias{tune.nnet}
\alias{best.nnet}
\alias{tune.randomForest}
\alias{best.randomForest}
\alias{tune.knn}
\alias{knn.wrapper}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Convenience tuning wrapper functions}
\description{
  Convenience tuning wrapper functions, using \code{tune}.
}
\usage{
tune.svm(x, y = NULL, data = NULL, degree = NULL, gamma = NULL, coef0 = NULL, cost = NULL, 
         nu = NULL, ...)
best.svm(x, ...)
 
tune.nnet(x, y = NULL, data = NULL, size = NULL, decay = NULL, trace = FALSE, nrepeat = 5, 
          ...)
best.nnet(x, ...)

tune.rpart(formula, data, na.action = na.omit, minsplit = NULL,
           minbucket = NULL, cp = NULL, maxcompete = NULL, maxsurrogate = NULL,
           usesurrogate = NULL, xval = NULL, surrogatestyle = NULL, maxdepth =
           NULL, predict.func = NULL, ...)
best.rpart(formula, ...)
rpart.wrapper(formula, minsplit=20, minbucket=round(minsplit/3), cp=0.01, 
              maxcompete=4, maxsurrogate=5, usesurrogate=2, xval=10,
              surrogatestyle=0, maxdepth=30, ...)

tune.randomForest(x, y = NULL, data = NULL, nodesize = NULL, mtry = NULL, ntree = NULL, ...)
best.randomForest(x, ...)

tune.knn(x, y, k = NULL, l = NULL, ...) 
knn.wrapper(x, y, k = 1, l = 0, ...)

}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{formula, x, y, data}{formula and data arguments of function to be tuned.}
  \item{predict.func}{predicting function.}
  \item{na.action}{function handling missingness.}
  \item{minsplit, minbucket, cp, maxcompete,
        maxsurrogate, usesurrogate, xval,
        surrogatestyle, maxdepth}{\code{rpart} parameters.}
  \item{degree, gamma, coef0, cost, nu}{\code{svm}
    parameters.}
  \item{k, l}{\code{knn} parameters.}
  \item{mtry, nodesize, ntree}{\code{randomForest} parameters.}
  \item{size, decay, nrepeat, trace}{\code{nnet} parameters.}
  \item{\dots}{Further parameters passed to \code{tune}.}
}

\value{
  \code{tune.foo()} returns a tuning object including the best parameter set obtained
  by optimizing over the specified parameter vectors. \code{best.foo()}
  directly returns the best model, i.e. the fit of a new model using the
  optimal parameters found by \code{tune.foo}.
}
\details{For examples, see the help page of \code{tune()}.}

\author{
  David Meyer\cr
  \email{david.meyer@ci.tuwien.ac.at}
}
\seealso{\code{\link{tune}}}

\keyword{models}% __ONLY ONE__ keyword per line
\eof
